/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLAppletElement.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLAppletElement.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLAppletElement.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLAppletElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLAppletElement::GDOMHTMLAppletElement(PassRefPtr<WebCore::HTMLAppletElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLAppletElement.h"
#include <gdom/GdomHTMLAppletElement.h>
#include <gdom/PrivateGdomHTMLAppletElement.h>
#include <gdom/PrivateIntGdomHTMLAppletElement.h>
#include <gdom/GdomHTMLAppletElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLAppletElement, gdom_html_applet_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLAppletElementPrivate {
    class WebCore::HTMLAppletElement *item;
};

#define GDOM_HTML_APPLET_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_APPLET_ELEMENT, GdomHTMLAppletElementPrivate))
*/
G_END_DECLS
WebCore::HTMLAppletElement *
gdom_html_applet_element_get_private(GdomHTMLAppletElement *request)
{
    GDOMHTMLAppletElement *res;
    res = static_cast<GDOMHTMLAppletElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLAppletElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ALIGN,
    PROP_ALT,
    PROP_ARCHIVE,
    PROP_CODE,
    PROP_CODE_BASE,
    PROP_HEIGHT,
    PROP_HSPACE,
    PROP_NAME,
    PROP_OBJECT,
    PROP_VSPACE,
    PROP_WIDTH,
};


static void gdom_html_applet_element_finalize(GObject* object)
{
    /*GdomHTMLAppletElement* request = GDOM_HTML_APPLET_ELEMENT(object);*/
    /*GdomHTMLAppletElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_applet_element_parent_class)->finalize(object);
}

static void gdom_html_applet_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAppletElement *self = GDOM_HTML_APPLET_ELEMENT(object);
    WebCore::HTMLAppletElement * gself = (gdom_html_applet_element_get_private(self));
    switch (prop_id) {
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ALT:
    {
         gself->setAlt(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ARCHIVE:
    {
         gself->setArchive(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CODE:
    {
         gself->setCode(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CODE_BASE:
    {
         gself->setCodeBase(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HEIGHT:
    {
         gself->setHeight(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HSPACE:
    {
         gself->setHspace(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NAME:
    {
         gself->setName(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_OBJECT:
    {
         gself->setObject(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_VSPACE:
    {
         gself->setVspace(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_WIDTH:
    {
         gself->setWidth(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_applet_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAppletElement *self = GDOM_HTML_APPLET_ELEMENT(object);
    WebCore::HTMLAppletElement * gself = (gdom_html_applet_element_get_private(self));
    switch (prop_id) {
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_ALT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->alt()));
         break;
    }
    case PROP_ARCHIVE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->archive()));
         break;
    }
    case PROP_CODE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->code()));
         break;
    }
    case PROP_CODE_BASE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->codeBase()));
         break;
    }
    case PROP_HEIGHT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->height()));
         break;
    }
    case PROP_HSPACE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hspace()));
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_OBJECT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->object()));
         break;
    }
    case PROP_VSPACE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->vspace()));
         break;
    }
    case PROP_WIDTH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->width()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_applet_element_class_init(GdomHTMLAppletElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_applet_element_finalize;
    g_klass->set_property = gdom_html_applet_element__set_property_fn;
    g_klass->get_property = gdom_html_applet_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_applet_element_align", /* short description */
                "read-write  gchar * HTMLAppletElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ALT,
            g_param_spec_string ("alt", /* name */
                "html_applet_element_alt", /* short description */
                "read-write  gchar * HTMLAppletElement.alt", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ARCHIVE,
            g_param_spec_string ("archive", /* name */
                "html_applet_element_archive", /* short description */
                "read-write  gchar * HTMLAppletElement.archive", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CODE,
            g_param_spec_string ("code", /* name */
                "html_applet_element_code", /* short description */
                "read-write  gchar * HTMLAppletElement.code", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CODE_BASE,
            g_param_spec_string ("code_base", /* name */
                "html_applet_element_code_base", /* short description */
                "read-write  gchar * HTMLAppletElement.code_base", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HEIGHT,
            g_param_spec_string ("height", /* name */
                "html_applet_element_height", /* short description */
                "read-write  gchar * HTMLAppletElement.height", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HSPACE,
            g_param_spec_string ("hspace", /* name */
                "html_applet_element_hspace", /* short description */
                "read-write  gchar * HTMLAppletElement.hspace", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "html_applet_element_name", /* short description */
                "read-write  gchar * HTMLAppletElement.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_OBJECT,
            g_param_spec_string ("object", /* name */
                "html_applet_element_object", /* short description */
                "read-write  gchar * HTMLAppletElement.object", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_VSPACE,
            g_param_spec_string ("vspace", /* name */
                "html_applet_element_vspace", /* short description */
                "read-write  gchar * HTMLAppletElement.vspace", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WIDTH,
            g_param_spec_string ("width", /* name */
                "html_applet_element_width", /* short description */
                "read-write  gchar * HTMLAppletElement.width", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLAppletElementPrivate));*/
}

static void gdom_html_applet_element_init(GdomHTMLAppletElement* request)
{
    /*GdomHTMLAppletElementPrivate* priv = GDOM_HTML_APPLET_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

